==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/PinnedAreaSeparatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DefinitionBaseDescriptionMetadata } from "./DefinitionBaseDescriptionMetadata";
import { PinnedAreaSeparatorDescription } from "./PinnedAreaSeparatorDescription";
/**
 * @hidden
 */
var PinnedAreaSeparatorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(PinnedAreaSeparatorDescriptionMetadata, _super);
    function PinnedAreaSeparatorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PinnedAreaSeparatorDescriptionMetadata.b = function (a) {
        if (PinnedAreaSeparatorDescriptionMetadata.a == null) {
            PinnedAreaSeparatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            PinnedAreaSeparatorDescriptionMetadata.c(PinnedAreaSeparatorDescriptionMetadata.a);
        }
        if (a.j(PinnedAreaSeparatorDescriptionMetadata.a)) {
            return;
        }
        a.y(PinnedAreaSeparatorDescriptionMetadata.a);
    };
    PinnedAreaSeparatorDescriptionMetadata.c = function (a) {
        DefinitionBaseDescriptionMetadata.c(a);
    };
    PinnedAreaSeparatorDescriptionMetadata.d = function (a) {
        PinnedAreaSeparatorDescriptionMetadata.b(a);
        a.aa("PinnedAreaSeparator", function () { return new PinnedAreaSeparatorDescription(); });
        a.z("PinnedAreaSeparator", PinnedAreaSeparatorDescriptionMetadata.a);
    };
    PinnedAreaSeparatorDescriptionMetadata.$t = markType(PinnedAreaSeparatorDescriptionMetadata, 'PinnedAreaSeparatorDescriptionMetadata');
    PinnedAreaSeparatorDescriptionMetadata.a = null;
    return PinnedAreaSeparatorDescriptionMetadata;
}(Base));
export { PinnedAreaSeparatorDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/PinnedAreaSeparatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DefinitionBaseDescriptionMetadata } from "./DefinitionBaseDescriptionMetadata";
import { PinnedAreaSeparatorDescription } from "./PinnedAreaSeparatorDescription";
/**
 * @hidden
 */
var PinnedAreaSeparatorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(PinnedAreaSeparatorDescriptionMetadata, _super);
    function PinnedAreaSeparatorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PinnedAreaSeparatorDescriptionMetadata.b = function (a) {
        if (PinnedAreaSeparatorDescriptionMetadata.a == null) {
            PinnedAreaSeparatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            PinnedAreaSeparatorDescriptionMetadata.c(PinnedAreaSeparatorDescriptionMetadata.a);
        }
        if (a.k(PinnedAreaSeparatorDescriptionMetadata.a)) {
            return;
        }
        a.aa(PinnedAreaSeparatorDescriptionMetadata.a);
    };
    PinnedAreaSeparatorDescriptionMetadata.c = function (a) {
        DefinitionBaseDescriptionMetadata.c(a);
    };
    PinnedAreaSeparatorDescriptionMetadata.d = function (a) {
        PinnedAreaSeparatorDescriptionMetadata.b(a);
        a.ac("PinnedAreaSeparator", function () { return new PinnedAreaSeparatorDescription(); });
        a.ab("PinnedAreaSeparator", PinnedAreaSeparatorDescriptionMetadata.a);
    };
    PinnedAreaSeparatorDescriptionMetadata.$t = markType(PinnedAreaSeparatorDescriptionMetadata, 'PinnedAreaSeparatorDescriptionMetadata');
    PinnedAreaSeparatorDescriptionMetadata.a = null;
    return PinnedAreaSeparatorDescriptionMetadata;
}(Base));
export { PinnedAreaSeparatorDescriptionMetadata };
